
using System;
using Gtk;
using IPod;

namespace Dopi {

    public class DevicePropertyEditor : Table {

        private Device device;
        private Entry nameEntry;

        public DevicePropertyEditor (Device device) : base (1, 1, false) {
            this.device = device;
            this.ColumnSpacing = 6;
            this.RowSpacing = 6;

            nameEntry = AddEntry ("Name", device.Name);
            nameEntry.Changed += OnNameChanged;
            
            AddLabel ("Model", device.Model);
            AddLabel ("Generation", device.Generation);
            AddLabel ("Capacity", device.AdvertisedCapacity);
            AddLabel ("Mount Point", device.MountPoint);
            AddLabel ("Space Used",
                      String.Format ("{0}%", (int) ((double) device.VolumeUsed / (double) device.VolumeSize * 100)));

            AddLabel ("Serial Number", device.SerialNumber);
            AddLabel ("Model Number", device.ModelNumber);
            AddLabel ("Firmware Version", device.FirmwareVersion);
            AddLabel ("Database Version", device.SongDatabase.Version);
        }

        private void OnNameChanged (object o, EventArgs args) {
            device.Name = nameEntry.Text;
        }

        private Label MakeLabel (string label) {
            Label l = new Label (String.Format ("<b>{0}:</b>", label));
            l.Xalign = 0.0f;
            l.UseMarkup = true;
            l.Show ();
            
            return l;
        }

        private Entry AddEntry (string label, string value) {
            uint rows = NRows;
            
            Attach (MakeLabel (label), 0, 1, rows, rows + 1);

            Entry entry = new Entry ();
            entry.Text = value;
            entry.Show ();
            
            Attach (entry, 1, 2, rows, rows + 1);
            
            return entry;
        }

        private void AddLabel (string label, object value) {
            uint rows = NRows;
            
            Attach (MakeLabel (label), 0, 1, rows, rows + 1);

            if (value == null)
                value = String.Empty;
            
            Label valLabel = new Label (value.ToString ());
            valLabel.Xalign = 0.0f;
            valLabel.UseUnderline = false;
            valLabel.Selectable = true;
            valLabel.Show ();
            
            Attach (valLabel, 1, 2, rows, rows + 1);
        }
    }
}
